======
Output
======

Sub-commands to support the output components


.. autosummary::
    :nosignatures:
    :toctree: _generated/

    rompy_swan.subcomponents.output.SPEC1D
    rompy_swan.subcomponents.output.SPEC2D
    rompy_swan.subcomponents.output.ABS
    rompy_swan.subcomponents.output.REL
